# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_appmesh.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61ws/aws_appmesh.proto\x12\x17oak9.tython.aws.appmesh\x1a\x13shared/shared.proto\"\x7f\n&GatewayRouteGatewayRouteVirtualService\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14virtual_service_name\x18\x02 \x01(\t\"\xb3\x01\n\x1eGatewayRouteGatewayRouteTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12X\n\x0fvirtual_service\x18\x02 \x01(\x0b\x32?.oak9.tython.aws.appmesh.GatewayRouteGatewayRouteVirtualService\"\xa6\x01\n\"GatewayRouteHttpGatewayRouteAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12G\n\x06target\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.appmesh.GatewayRouteGatewayRouteTarget\"l\n!GatewayRouteHttpGatewayRouteMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06prefix\x18\x02 \x01(\t\"\xef\x01\n\x1cGatewayRouteHttpGatewayRoute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12K\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32;.oak9.tython.aws.appmesh.GatewayRouteHttpGatewayRouteAction\x12I\n\x05match\x18\x03 \x01(\x0b\x32:.oak9.tython.aws.appmesh.GatewayRouteHttpGatewayRouteMatch\"\xa6\x01\n\"GatewayRouteGrpcGatewayRouteAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12G\n\x06target\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.appmesh.GatewayRouteGatewayRouteTarget\"r\n!GatewayRouteGrpcGatewayRouteMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cservice_name\x18\x02 \x01(\t\"\xef\x01\n\x1cGatewayRouteGrpcGatewayRoute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12K\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32;.oak9.tython.aws.appmesh.GatewayRouteGrpcGatewayRouteAction\x12I\n\x05match\x18\x03 \x01(\x0b\x32:.oak9.tython.aws.appmesh.GatewayRouteGrpcGatewayRouteMatch\"\xb9\x02\n\x1cGatewayRouteGatewayRouteSpec\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12I\n\nhttp_route\x18\x02 \x01(\x0b\x32\x35.oak9.tython.aws.appmesh.GatewayRouteHttpGatewayRoute\x12J\n\x0bhttp2_route\x18\x03 \x01(\x0b\x32\x35.oak9.tython.aws.appmesh.GatewayRouteHttpGatewayRoute\x12I\n\ngrpc_route\x18\x04 \x01(\x0b\x32\x35.oak9.tython.aws.appmesh.GatewayRouteGrpcGatewayRoute\"\xd9\x02\n\x0cGatewayRoute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tmesh_name\x18\x02 \x01(\t\x12\x1c\n\x14virtual_gateway_name\x18\x03 \x01(\t\x12\x12\n\nmesh_owner\x18\x04 \x01(\t\x12\x1a\n\x12gateway_route_name\x18\x05 \x01(\t\x12\x43\n\x04spec\x18\x06 \x01(\x0b\x32\x35.oak9.tython.aws.appmesh.GatewayRouteGatewayRouteSpec\x12=\n\x04tags\x18\x07 \x03(\x0b\x32/.oak9.tython.aws.appmesh.GatewayRoute.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa3\x03\n\x07\x41ppMesh\x12<\n\rgateway_route\x18\x01 \x03(\x0b\x32%.oak9.tython.aws.appmesh.GatewayRoute\x12+\n\x04mesh\x18\x02 \x03(\x0b\x32\x1d.oak9.tython.aws.appmesh.Mesh\x12-\n\x05route\x18\x03 \x03(\x0b\x32\x1e.oak9.tython.aws.appmesh.Route\x12@\n\x0fvirtual_gateway\x18\x04 \x03(\x0b\x32\'.oak9.tython.aws.appmesh.VirtualGateway\x12:\n\x0cvirtual_node\x18\x05 \x03(\x0b\x32$.oak9.tython.aws.appmesh.VirtualNode\x12>\n\x0evirtual_router\x18\x06 \x03(\x0b\x32&.oak9.tython.aws.appmesh.VirtualRouter\x12@\n\x0fvirtual_service\x18\x07 \x03(\x0b\x32\'.oak9.tython.aws.appmesh.VirtualService\"K\n\x10MeshEgressFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x89\x01\n\x0cMeshMeshSpec\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12@\n\regress_filter\x18\x02 \x01(\x0b\x32).oak9.tython.aws.appmesh.MeshEgressFilter\"\xeb\x01\n\x04Mesh\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tmesh_name\x18\x02 \x01(\t\x12\x33\n\x04spec\x18\x03 \x01(\x0b\x32%.oak9.tython.aws.appmesh.MeshMeshSpec\x12\x35\n\x04tags\x18\x04 \x03(\x0b\x32\'.oak9.tython.aws.appmesh.Mesh.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"t\n\x13RouteWeightedTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cvirtual_node\x18\x02 \x01(\t\x12\x0e\n\x06weight\x18\x03 \x01(\x05\"\x97\x01\n\x14RouteHttpRouteAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x46\n\x10weighted_targets\x18\x02 \x03(\x0b\x32,.oak9.tython.aws.appmesh.RouteWeightedTarget\"e\n\rRouteDuration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\x05\x12\x0c\n\x04unit\x18\x03 \x01(\t\"\xbe\x01\n\x10RouteHttpTimeout\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12;\n\x0bper_request\x18\x02 \x01(\x0b\x32&.oak9.tython.aws.appmesh.RouteDuration\x12\x34\n\x04idle\x18\x03 \x01(\x0b\x32&.oak9.tython.aws.appmesh.RouteDuration\"\xdc\x01\n\x14RouteHttpRetryPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bmax_retries\x18\x02 \x01(\x05\x12\x41\n\x11per_retry_timeout\x18\x03 \x01(\x0b\x32&.oak9.tython.aws.appmesh.RouteDuration\x12\x19\n\x11http_retry_events\x18\x04 \x03(\t\x12\x18\n\x10tcp_retry_events\x18\x05 \x03(\t\"f\n\x0fRouteMatchRange\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05start\x18\x02 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x05\"\xc8\x01\n\x16RouteHeaderMatchMethod\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06suffix\x18\x02 \x01(\t\x12\r\n\x05regex\x18\x03 \x01(\t\x12\r\n\x05\x65xact\x18\x04 \x01(\t\x12\x0e\n\x06prefix\x18\x05 \x01(\t\x12\x37\n\x05range\x18\x06 \x01(\x0b\x32(.oak9.tython.aws.appmesh.RouteMatchRange\"\xad\x01\n\x14RouteHttpRouteHeader\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06invert\x18\x02 \x01(\x08\x12\x0c\n\x04name\x18\x03 \x01(\t\x12>\n\x05match\x18\x04 \x01(\x0b\x32/.oak9.tython.aws.appmesh.RouteHeaderMatchMethod\"\xbe\x01\n\x13RouteHttpRouteMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06scheme\x18\x02 \x01(\t\x12>\n\x07headers\x18\x03 \x03(\x0b\x32-.oak9.tython.aws.appmesh.RouteHttpRouteHeader\x12\x0e\n\x06prefix\x18\x04 \x01(\t\x12\x0e\n\x06method\x18\x05 \x01(\t\"\xc6\x02\n\x0eRouteHttpRoute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32-.oak9.tython.aws.appmesh.RouteHttpRouteAction\x12:\n\x07timeout\x18\x03 \x01(\x0b\x32).oak9.tython.aws.appmesh.RouteHttpTimeout\x12\x43\n\x0cretry_policy\x18\x04 \x01(\x0b\x32-.oak9.tython.aws.appmesh.RouteHttpRetryPolicy\x12;\n\x05match\x18\x05 \x01(\x0b\x32,.oak9.tython.aws.appmesh.RouteHttpRouteMatch\"\x97\x01\n\x14RouteGrpcRouteAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x46\n\x10weighted_targets\x18\x02 \x03(\x0b\x32,.oak9.tython.aws.appmesh.RouteWeightedTarget\"\xbe\x01\n\x10RouteGrpcTimeout\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12;\n\x0bper_request\x18\x02 \x01(\x0b\x32&.oak9.tython.aws.appmesh.RouteDuration\x12\x34\n\x04idle\x18\x03 \x01(\x0b\x32&.oak9.tython.aws.appmesh.RouteDuration\"\xf7\x01\n\x14RouteGrpcRetryPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bmax_retries\x18\x02 \x01(\x05\x12\x41\n\x11per_retry_timeout\x18\x03 \x01(\x0b\x32&.oak9.tython.aws.appmesh.RouteDuration\x12\x19\n\x11grpc_retry_events\x18\x04 \x03(\t\x12\x19\n\x11http_retry_events\x18\x05 \x03(\t\x12\x18\n\x10tcp_retry_events\x18\x06 \x03(\t\"\xd3\x01\n!RouteGrpcRouteMetadataMatchMethod\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06suffix\x18\x02 \x01(\t\x12\r\n\x05regex\x18\x03 \x01(\t\x12\r\n\x05\x65xact\x18\x04 \x01(\t\x12\x0e\n\x06prefix\x18\x05 \x01(\t\x12\x37\n\x05range\x18\x06 \x01(\x0b\x32(.oak9.tython.aws.appmesh.RouteMatchRange\"\xba\x01\n\x16RouteGrpcRouteMetadata\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06invert\x18\x02 \x01(\x08\x12\x0c\n\x04name\x18\x03 \x01(\t\x12I\n\x05match\x18\x04 \x01(\x0b\x32:.oak9.tython.aws.appmesh.RouteGrpcRouteMetadataMatchMethod\"\xbc\x01\n\x13RouteGrpcRouteMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cservice_name\x18\x02 \x01(\t\x12\x41\n\x08metadata\x18\x03 \x03(\x0b\x32/.oak9.tython.aws.appmesh.RouteGrpcRouteMetadata\x12\x13\n\x0bmethod_name\x18\x04 \x01(\t\"\xc6\x02\n\x0eRouteGrpcRoute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32-.oak9.tython.aws.appmesh.RouteGrpcRouteAction\x12:\n\x07timeout\x18\x03 \x01(\x0b\x32).oak9.tython.aws.appmesh.RouteGrpcTimeout\x12\x43\n\x0cretry_policy\x18\x04 \x01(\x0b\x32-.oak9.tython.aws.appmesh.RouteGrpcRetryPolicy\x12;\n\x05match\x18\x05 \x01(\x0b\x32,.oak9.tython.aws.appmesh.RouteGrpcRouteMatch\"\x96\x01\n\x13RouteTcpRouteAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x46\n\x10weighted_targets\x18\x02 \x03(\x0b\x32,.oak9.tython.aws.appmesh.RouteWeightedTarget\"\x80\x01\n\x0fRouteTcpTimeout\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x34\n\x04idle\x18\x02 \x01(\x0b\x32&.oak9.tython.aws.appmesh.RouteDuration\"\xc1\x01\n\rRouteTcpRoute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12<\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32,.oak9.tython.aws.appmesh.RouteTcpRouteAction\x12\x39\n\x07timeout\x18\x03 \x01(\x0b\x32(.oak9.tython.aws.appmesh.RouteTcpTimeout\"\xce\x02\n\x0eRouteRouteSpec\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12;\n\nhttp_route\x18\x02 \x01(\x0b\x32\'.oak9.tython.aws.appmesh.RouteHttpRoute\x12\x10\n\x08priority\x18\x03 \x01(\x05\x12<\n\x0bhttp2_route\x18\x04 \x01(\x0b\x32\'.oak9.tython.aws.appmesh.RouteHttpRoute\x12;\n\ngrpc_route\x18\x05 \x01(\x0b\x32\'.oak9.tython.aws.appmesh.RouteGrpcRoute\x12\x39\n\ttcp_route\x18\x06 \x01(\x0b\x32&.oak9.tython.aws.appmesh.RouteTcpRoute\"\xb4\x02\n\x05Route\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tmesh_name\x18\x02 \x01(\t\x12\x1b\n\x13virtual_router_name\x18\x03 \x01(\t\x12\x12\n\nmesh_owner\x18\x04 \x01(\t\x12\x12\n\nroute_name\x18\x05 \x01(\t\x12\x35\n\x04spec\x18\x06 \x01(\x0b\x32\'.oak9.tython.aws.appmesh.RouteRouteSpec\x12\x36\n\x04tags\x18\x07 \x03(\x0b\x32(.oak9.tython.aws.appmesh.Route.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"r\n)VirtualGatewayVirtualGatewayFileAccessLog\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04path\x18\x02 \x01(\t\"\xb2\x01\n%VirtualGatewayVirtualGatewayAccessLog\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x04\x66ile\x18\x02 \x01(\x0b\x32\x42.oak9.tython.aws.appmesh.VirtualGatewayVirtualGatewayFileAccessLog\"\xb2\x01\n#VirtualGatewayVirtualGatewayLogging\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\naccess_log\x18\x02 \x01(\x0b\x32>.oak9.tython.aws.appmesh.VirtualGatewayVirtualGatewayAccessLog\"\xff\x01\n-VirtualGatewayVirtualGatewayHealthCheckPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x1b\n\x13unhealthy_threshold\x18\x03 \x01(\x05\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\x19\n\x11healthy_threshold\x18\x05 \x01(\x05\x12\x16\n\x0etimeout_millis\x18\x06 \x01(\x05\x12\x10\n\x08protocol\x18\x07 \x01(\t\x12\x17\n\x0finterval_millis\x18\x08 \x01(\x05\"\x89\x01\n5VirtualGatewayVirtualGatewayListenerTlsAcmCertificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x02 \x01(\t\"\xa1\x01\n6VirtualGatewayVirtualGatewayListenerTlsFileCertificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bprivate_key\x18\x02 \x01(\t\x12\x19\n\x11\x63\x65rtificate_chain\x18\x03 \x01(\t\"\xa9\x02\n2VirtualGatewayVirtualGatewayListenerTlsCertificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12[\n\x03\x61\x63m\x18\x02 \x01(\x0b\x32N.oak9.tython.aws.appmesh.VirtualGatewayVirtualGatewayListenerTlsAcmCertificate\x12]\n\x04\x66ile\x18\x03 \x01(\x0b\x32O.oak9.tython.aws.appmesh.VirtualGatewayVirtualGatewayListenerTlsFileCertificate\"\xd2\x01\n\'VirtualGatewayVirtualGatewayListenerTls\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04mode\x18\x02 \x01(\t\x12`\n\x0b\x63\x65rtificate\x18\x03 \x01(\x0b\x32K.oak9.tython.aws.appmesh.VirtualGatewayVirtualGatewayListenerTlsCertificate\"\x82\x01\n\'VirtualGatewayVirtualGatewayPortMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x10\n\x08protocol\x18\x03 \x01(\t\"\xe4\x02\n$VirtualGatewayVirtualGatewayListener\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\\\n\x0chealth_check\x18\x02 \x01(\x0b\x32\x46.oak9.tython.aws.appmesh.VirtualGatewayVirtualGatewayHealthCheckPolicy\x12M\n\x03tls\x18\x03 \x01(\x0b\x32@.oak9.tython.aws.appmesh.VirtualGatewayVirtualGatewayListenerTls\x12V\n\x0cport_mapping\x18\x04 \x01(\x0b\x32@.oak9.tython.aws.appmesh.VirtualGatewayVirtualGatewayPortMapping\"\x97\x01\n8VirtualGatewayVirtualGatewayTlsValidationContextAcmTrust\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\"\n\x1a\x63\x65rtificate_authority_arns\x18\x02 \x03(\t\"\x8f\x01\n9VirtualGatewayVirtualGatewayTlsValidationContextFileTrust\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x63\x65rtificate_chain\x18\x02 \x01(\t\"\xb2\x02\n5VirtualGatewayVirtualGatewayTlsValidationContextTrust\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12^\n\x03\x61\x63m\x18\x02 \x01(\x0b\x32Q.oak9.tython.aws.appmesh.VirtualGatewayVirtualGatewayTlsValidationContextAcmTrust\x12`\n\x04\x66ile\x18\x03 \x01(\x0b\x32R.oak9.tython.aws.appmesh.VirtualGatewayVirtualGatewayTlsValidationContextFileTrust\"\xca\x01\n0VirtualGatewayVirtualGatewayTlsValidationContext\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12]\n\x05trust\x18\x02 \x01(\x0b\x32N.oak9.tython.aws.appmesh.VirtualGatewayVirtualGatewayTlsValidationContextTrust\"\xe5\x01\n+VirtualGatewayVirtualGatewayClientPolicyTls\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12]\n\nvalidation\x18\x02 \x01(\x0b\x32I.oak9.tython.aws.appmesh.VirtualGatewayVirtualGatewayTlsValidationContext\x12\x0f\n\x07\x65nforce\x18\x03 \x01(\x08\x12\r\n\x05ports\x18\x04 \x03(\x05\"\xb6\x01\n(VirtualGatewayVirtualGatewayClientPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Q\n\x03tls\x18\x02 \x01(\x0b\x32\x44.oak9.tython.aws.appmesh.VirtualGatewayVirtualGatewayClientPolicyTls\"\xc0\x01\n+VirtualGatewayVirtualGatewayBackendDefaults\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12X\n\rclient_policy\x18\x02 \x01(\x0b\x32\x41.oak9.tython.aws.appmesh.VirtualGatewayVirtualGatewayClientPolicy\"\xdc\x02\n VirtualGatewayVirtualGatewaySpec\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x07logging\x18\x02 \x01(\x0b\x32<.oak9.tython.aws.appmesh.VirtualGatewayVirtualGatewayLogging\x12P\n\tlisteners\x18\x03 \x03(\x0b\x32=.oak9.tython.aws.appmesh.VirtualGatewayVirtualGatewayListener\x12^\n\x10\x62\x61\x63kend_defaults\x18\x04 \x01(\x0b\x32\x44.oak9.tython.aws.appmesh.VirtualGatewayVirtualGatewayBackendDefaults\"\xc5\x02\n\x0eVirtualGateway\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14virtual_gateway_name\x18\x02 \x01(\t\x12\x11\n\tmesh_name\x18\x03 \x01(\t\x12\x12\n\nmesh_owner\x18\x04 \x01(\t\x12G\n\x04spec\x18\x05 \x01(\x0b\x32\x39.oak9.tython.aws.appmesh.VirtualGatewayVirtualGatewaySpec\x12?\n\x04tags\x18\x06 \x03(\x0b\x32\x31.oak9.tython.aws.appmesh.VirtualGateway.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"a\n\x18VirtualNodeFileAccessLog\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04path\x18\x02 \x01(\t\"\x90\x01\n\x14VirtualNodeAccessLog\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12?\n\x04\x66ile\x18\x02 \x01(\x0b\x32\x31.oak9.tython.aws.appmesh.VirtualNodeFileAccessLog\"\x90\x01\n\x12VirtualNodeLogging\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\naccess_log\x18\x02 \x01(\x0b\x32-.oak9.tython.aws.appmesh.VirtualNodeAccessLog\"\x86\x01\n\'VirtualNodeTlsValidationContextAcmTrust\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\"\n\x1a\x63\x65rtificate_authority_arns\x18\x02 \x03(\t\"~\n(VirtualNodeTlsValidationContextFileTrust\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x63\x65rtificate_chain\x18\x02 \x01(\t\"\xff\x01\n$VirtualNodeTlsValidationContextTrust\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x03\x61\x63m\x18\x02 \x01(\x0b\x32@.oak9.tython.aws.appmesh.VirtualNodeTlsValidationContextAcmTrust\x12O\n\x04\x66ile\x18\x03 \x01(\x0b\x32\x41.oak9.tython.aws.appmesh.VirtualNodeTlsValidationContextFileTrust\"\xa8\x01\n\x1fVirtualNodeTlsValidationContext\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12L\n\x05trust\x18\x02 \x01(\x0b\x32=.oak9.tython.aws.appmesh.VirtualNodeTlsValidationContextTrust\"\xc3\x01\n\x1aVirtualNodeClientPolicyTls\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12L\n\nvalidation\x18\x02 \x01(\x0b\x32\x38.oak9.tython.aws.appmesh.VirtualNodeTlsValidationContext\x12\x0f\n\x07\x65nforce\x18\x03 \x01(\x08\x12\r\n\x05ports\x18\x04 \x03(\x05\"\x94\x01\n\x17VirtualNodeClientPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12@\n\x03tls\x18\x02 \x01(\x0b\x32\x33.oak9.tython.aws.appmesh.VirtualNodeClientPolicyTls\"\xc2\x01\n VirtualNodeVirtualServiceBackend\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12G\n\rclient_policy\x18\x02 \x01(\x0b\x32\x30.oak9.tython.aws.appmesh.VirtualNodeClientPolicy\x12\x1c\n\x14virtual_service_name\x18\x03 \x01(\t\"\xa1\x01\n\x12VirtualNodeBackend\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x0fvirtual_service\x18\x02 \x01(\x0b\x32\x39.oak9.tython.aws.appmesh.VirtualNodeVirtualServiceBackend\"k\n\x13VirtualNodeDuration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\x05\x12\x0c\n\x04unit\x18\x03 \x01(\t\"\x8c\x01\n\x15VirtualNodeTcpTimeout\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12:\n\x04idle\x18\x02 \x01(\x0b\x32,.oak9.tython.aws.appmesh.VirtualNodeDuration\"\xd0\x01\n\x16VirtualNodeHttpTimeout\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\x0bper_request\x18\x02 \x01(\x0b\x32,.oak9.tython.aws.appmesh.VirtualNodeDuration\x12:\n\x04idle\x18\x03 \x01(\x0b\x32,.oak9.tython.aws.appmesh.VirtualNodeDuration\"\xd0\x01\n\x16VirtualNodeGrpcTimeout\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\x0bper_request\x18\x02 \x01(\x0b\x32,.oak9.tython.aws.appmesh.VirtualNodeDuration\x12:\n\x04idle\x18\x03 \x01(\x0b\x32,.oak9.tython.aws.appmesh.VirtualNodeDuration\"\xd0\x02\n\x1aVirtualNodeListenerTimeout\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12;\n\x03tcp\x18\x02 \x01(\x0b\x32..oak9.tython.aws.appmesh.VirtualNodeTcpTimeout\x12>\n\x05http2\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.appmesh.VirtualNodeHttpTimeout\x12=\n\x04http\x18\x04 \x01(\x0b\x32/.oak9.tython.aws.appmesh.VirtualNodeHttpTimeout\x12=\n\x04grpc\x18\x05 \x01(\x0b\x32/.oak9.tython.aws.appmesh.VirtualNodeGrpcTimeout\"\xe8\x01\n\x16VirtualNodeHealthCheck\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x1b\n\x13unhealthy_threshold\x18\x03 \x01(\x05\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\x19\n\x11healthy_threshold\x18\x05 \x01(\x05\x12\x16\n\x0etimeout_millis\x18\x06 \x01(\x05\x12\x10\n\x08protocol\x18\x07 \x01(\t\x12\x17\n\x0finterval_millis\x18\x08 \x01(\x05\"x\n$VirtualNodeListenerTlsAcmCertificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x02 \x01(\t\"\x90\x01\n%VirtualNodeListenerTlsFileCertificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bprivate_key\x18\x02 \x01(\t\x12\x19\n\x11\x63\x65rtificate_chain\x18\x03 \x01(\t\"\xf6\x01\n!VirtualNodeListenerTlsCertificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12J\n\x03\x61\x63m\x18\x02 \x01(\x0b\x32=.oak9.tython.aws.appmesh.VirtualNodeListenerTlsAcmCertificate\x12L\n\x04\x66ile\x18\x03 \x01(\x0b\x32>.oak9.tython.aws.appmesh.VirtualNodeListenerTlsFileCertificate\"\xb0\x01\n\x16VirtualNodeListenerTls\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04mode\x18\x02 \x01(\t\x12O\n\x0b\x63\x65rtificate\x18\x03 \x01(\x0b\x32:.oak9.tython.aws.appmesh.VirtualNodeListenerTlsCertificate\"q\n\x16VirtualNodePortMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x10\n\x08protocol\x18\x03 \x01(\t\"\xe0\x02\n\x13VirtualNodeListener\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\x07timeout\x18\x02 \x01(\x0b\x32\x33.oak9.tython.aws.appmesh.VirtualNodeListenerTimeout\x12\x45\n\x0chealth_check\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.appmesh.VirtualNodeHealthCheck\x12<\n\x03tls\x18\x04 \x01(\x0b\x32/.oak9.tython.aws.appmesh.VirtualNodeListenerTls\x12\x45\n\x0cport_mapping\x18\x05 \x01(\x0b\x32/.oak9.tython.aws.appmesh.VirtualNodePortMapping\"\x9e\x01\n\x1aVirtualNodeBackendDefaults\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12G\n\rclient_policy\x18\x02 \x01(\x0b\x32\x30.oak9.tython.aws.appmesh.VirtualNodeClientPolicy\"k\n\x1eVirtualNodeDnsServiceDiscovery\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08hostname\x18\x02 \x01(\t\"~\n\'VirtualNodeAwsCloudMapInstanceAttribute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xe5\x01\n&VirtualNodeAwsCloudMapServiceDiscovery\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0enamespace_name\x18\x02 \x01(\t\x12\x14\n\x0cservice_name\x18\x03 \x01(\t\x12T\n\nattributes\x18\x04 \x03(\x0b\x32@.oak9.tython.aws.appmesh.VirtualNodeAwsCloudMapInstanceAttribute\"\xf4\x01\n\x1bVirtualNodeServiceDiscovery\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\x03\x64ns\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.appmesh.VirtualNodeDnsServiceDiscovery\x12V\n\raws_cloud_map\x18\x03 \x01(\x0b\x32?.oak9.tython.aws.appmesh.VirtualNodeAwsCloudMapServiceDiscovery\"\xb3\x03\n\x1aVirtualNodeVirtualNodeSpec\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12<\n\x07logging\x18\x02 \x01(\x0b\x32+.oak9.tython.aws.appmesh.VirtualNodeLogging\x12=\n\x08\x62\x61\x63kends\x18\x03 \x03(\x0b\x32+.oak9.tython.aws.appmesh.VirtualNodeBackend\x12?\n\tlisteners\x18\x04 \x03(\x0b\x32,.oak9.tython.aws.appmesh.VirtualNodeListener\x12M\n\x10\x62\x61\x63kend_defaults\x18\x05 \x01(\x0b\x32\x33.oak9.tython.aws.appmesh.VirtualNodeBackendDefaults\x12O\n\x11service_discovery\x18\x06 \x01(\x0b\x32\x34.oak9.tython.aws.appmesh.VirtualNodeServiceDiscovery\"\xb6\x02\n\x0bVirtualNode\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tmesh_name\x18\x02 \x01(\t\x12\x12\n\nmesh_owner\x18\x03 \x01(\t\x12\x41\n\x04spec\x18\x04 \x01(\x0b\x32\x33.oak9.tython.aws.appmesh.VirtualNodeVirtualNodeSpec\x12\x19\n\x11virtual_node_name\x18\x05 \x01(\t\x12<\n\x04tags\x18\x06 \x03(\x0b\x32..oak9.tython.aws.appmesh.VirtualNode.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"s\n\x18VirtualRouterPortMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x10\n\x08protocol\x18\x03 \x01(\t\"\xa6\x01\n\"VirtualRouterVirtualRouterListener\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12G\n\x0cport_mapping\x18\x02 \x01(\x0b\x32\x31.oak9.tython.aws.appmesh.VirtualRouterPortMapping\"\xa9\x01\n\x1eVirtualRouterVirtualRouterSpec\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12N\n\tlisteners\x18\x02 \x03(\x0b\x32;.oak9.tython.aws.appmesh.VirtualRouterVirtualRouterListener\"\xc0\x02\n\rVirtualRouter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tmesh_name\x18\x02 \x01(\t\x12\x1b\n\x13virtual_router_name\x18\x03 \x01(\t\x12\x12\n\nmesh_owner\x18\x04 \x01(\t\x12\x45\n\x04spec\x18\x05 \x01(\x0b\x32\x37.oak9.tython.aws.appmesh.VirtualRouterVirtualRouterSpec\x12>\n\x04tags\x18\x06 \x03(\x0b\x32\x30.oak9.tython.aws.appmesh.VirtualRouter.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"~\n(VirtualServiceVirtualNodeServiceProvider\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11virtual_node_name\x18\x02 \x01(\t\"\x82\x01\n*VirtualServiceVirtualRouterServiceProvider\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13virtual_router_name\x18\x02 \x01(\t\"\x95\x02\n$VirtualServiceVirtualServiceProvider\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12W\n\x0cvirtual_node\x18\x02 \x01(\x0b\x32\x41.oak9.tython.aws.appmesh.VirtualServiceVirtualNodeServiceProvider\x12[\n\x0evirtual_router\x18\x03 \x01(\x0b\x32\x43.oak9.tython.aws.appmesh.VirtualServiceVirtualRouterServiceProvider\"\xac\x01\n VirtualServiceVirtualServiceSpec\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12O\n\x08provider\x18\x02 \x01(\x0b\x32=.oak9.tython.aws.appmesh.VirtualServiceVirtualServiceProvider\"\xc5\x02\n\x0eVirtualService\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tmesh_name\x18\x02 \x01(\t\x12\x12\n\nmesh_owner\x18\x03 \x01(\t\x12\x1c\n\x14virtual_service_name\x18\x04 \x01(\t\x12G\n\x04spec\x18\x05 \x01(\x0b\x32\x39.oak9.tython.aws.appmesh.VirtualServiceVirtualServiceSpec\x12?\n\x04tags\x18\x06 \x03(\x0b\x32\x31.oak9.tython.aws.appmesh.VirtualService.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_appmesh_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GATEWAYROUTE_TAGSENTRY._options = None
  _GATEWAYROUTE_TAGSENTRY._serialized_options = b'8\001'
  _MESH_TAGSENTRY._options = None
  _MESH_TAGSENTRY._serialized_options = b'8\001'
  _ROUTE_TAGSENTRY._options = None
  _ROUTE_TAGSENTRY._serialized_options = b'8\001'
  _VIRTUALGATEWAY_TAGSENTRY._options = None
  _VIRTUALGATEWAY_TAGSENTRY._serialized_options = b'8\001'
  _VIRTUALNODE_TAGSENTRY._options = None
  _VIRTUALNODE_TAGSENTRY._serialized_options = b'8\001'
  _VIRTUALROUTER_TAGSENTRY._options = None
  _VIRTUALROUTER_TAGSENTRY._serialized_options = b'8\001'
  _VIRTUALSERVICE_TAGSENTRY._options = None
  _VIRTUALSERVICE_TAGSENTRY._serialized_options = b'8\001'
  _GATEWAYROUTEGATEWAYROUTEVIRTUALSERVICE._serialized_start=71
  _GATEWAYROUTEGATEWAYROUTEVIRTUALSERVICE._serialized_end=198
  _GATEWAYROUTEGATEWAYROUTETARGET._serialized_start=201
  _GATEWAYROUTEGATEWAYROUTETARGET._serialized_end=380
  _GATEWAYROUTEHTTPGATEWAYROUTEACTION._serialized_start=383
  _GATEWAYROUTEHTTPGATEWAYROUTEACTION._serialized_end=549
  _GATEWAYROUTEHTTPGATEWAYROUTEMATCH._serialized_start=551
  _GATEWAYROUTEHTTPGATEWAYROUTEMATCH._serialized_end=659
  _GATEWAYROUTEHTTPGATEWAYROUTE._serialized_start=662
  _GATEWAYROUTEHTTPGATEWAYROUTE._serialized_end=901
  _GATEWAYROUTEGRPCGATEWAYROUTEACTION._serialized_start=904
  _GATEWAYROUTEGRPCGATEWAYROUTEACTION._serialized_end=1070
  _GATEWAYROUTEGRPCGATEWAYROUTEMATCH._serialized_start=1072
  _GATEWAYROUTEGRPCGATEWAYROUTEMATCH._serialized_end=1186
  _GATEWAYROUTEGRPCGATEWAYROUTE._serialized_start=1189
  _GATEWAYROUTEGRPCGATEWAYROUTE._serialized_end=1428
  _GATEWAYROUTEGATEWAYROUTESPEC._serialized_start=1431
  _GATEWAYROUTEGATEWAYROUTESPEC._serialized_end=1744
  _GATEWAYROUTE._serialized_start=1747
  _GATEWAYROUTE._serialized_end=2092
  _GATEWAYROUTE_TAGSENTRY._serialized_start=2049
  _GATEWAYROUTE_TAGSENTRY._serialized_end=2092
  _APPMESH._serialized_start=2095
  _APPMESH._serialized_end=2514
  _MESHEGRESSFILTER._serialized_start=2516
  _MESHEGRESSFILTER._serialized_end=2591
  _MESHMESHSPEC._serialized_start=2594
  _MESHMESHSPEC._serialized_end=2731
  _MESH._serialized_start=2734
  _MESH._serialized_end=2969
  _MESH_TAGSENTRY._serialized_start=2049
  _MESH_TAGSENTRY._serialized_end=2092
  _ROUTEWEIGHTEDTARGET._serialized_start=2971
  _ROUTEWEIGHTEDTARGET._serialized_end=3087
  _ROUTEHTTPROUTEACTION._serialized_start=3090
  _ROUTEHTTPROUTEACTION._serialized_end=3241
  _ROUTEDURATION._serialized_start=3243
  _ROUTEDURATION._serialized_end=3344
  _ROUTEHTTPTIMEOUT._serialized_start=3347
  _ROUTEHTTPTIMEOUT._serialized_end=3537
  _ROUTEHTTPRETRYPOLICY._serialized_start=3540
  _ROUTEHTTPRETRYPOLICY._serialized_end=3760
  _ROUTEMATCHRANGE._serialized_start=3762
  _ROUTEMATCHRANGE._serialized_end=3864
  _ROUTEHEADERMATCHMETHOD._serialized_start=3867
  _ROUTEHEADERMATCHMETHOD._serialized_end=4067
  _ROUTEHTTPROUTEHEADER._serialized_start=4070
  _ROUTEHTTPROUTEHEADER._serialized_end=4243
  _ROUTEHTTPROUTEMATCH._serialized_start=4246
  _ROUTEHTTPROUTEMATCH._serialized_end=4436
  _ROUTEHTTPROUTE._serialized_start=4439
  _ROUTEHTTPROUTE._serialized_end=4765
  _ROUTEGRPCROUTEACTION._serialized_start=4768
  _ROUTEGRPCROUTEACTION._serialized_end=4919
  _ROUTEGRPCTIMEOUT._serialized_start=4922
  _ROUTEGRPCTIMEOUT._serialized_end=5112
  _ROUTEGRPCRETRYPOLICY._serialized_start=5115
  _ROUTEGRPCRETRYPOLICY._serialized_end=5362
  _ROUTEGRPCROUTEMETADATAMATCHMETHOD._serialized_start=5365
  _ROUTEGRPCROUTEMETADATAMATCHMETHOD._serialized_end=5576
  _ROUTEGRPCROUTEMETADATA._serialized_start=5579
  _ROUTEGRPCROUTEMETADATA._serialized_end=5765
  _ROUTEGRPCROUTEMATCH._serialized_start=5768
  _ROUTEGRPCROUTEMATCH._serialized_end=5956
  _ROUTEGRPCROUTE._serialized_start=5959
  _ROUTEGRPCROUTE._serialized_end=6285
  _ROUTETCPROUTEACTION._serialized_start=6288
  _ROUTETCPROUTEACTION._serialized_end=6438
  _ROUTETCPTIMEOUT._serialized_start=6441
  _ROUTETCPTIMEOUT._serialized_end=6569
  _ROUTETCPROUTE._serialized_start=6572
  _ROUTETCPROUTE._serialized_end=6765
  _ROUTEROUTESPEC._serialized_start=6768
  _ROUTEROUTESPEC._serialized_end=7102
  _ROUTE._serialized_start=7105
  _ROUTE._serialized_end=7413
  _ROUTE_TAGSENTRY._serialized_start=2049
  _ROUTE_TAGSENTRY._serialized_end=2092
  _VIRTUALGATEWAYVIRTUALGATEWAYFILEACCESSLOG._serialized_start=7415
  _VIRTUALGATEWAYVIRTUALGATEWAYFILEACCESSLOG._serialized_end=7529
  _VIRTUALGATEWAYVIRTUALGATEWAYACCESSLOG._serialized_start=7532
  _VIRTUALGATEWAYVIRTUALGATEWAYACCESSLOG._serialized_end=7710
  _VIRTUALGATEWAYVIRTUALGATEWAYLOGGING._serialized_start=7713
  _VIRTUALGATEWAYVIRTUALGATEWAYLOGGING._serialized_end=7891
  _VIRTUALGATEWAYVIRTUALGATEWAYHEALTHCHECKPOLICY._serialized_start=7894
  _VIRTUALGATEWAYVIRTUALGATEWAYHEALTHCHECKPOLICY._serialized_end=8149
  _VIRTUALGATEWAYVIRTUALGATEWAYLISTENERTLSACMCERTIFICATE._serialized_start=8152
  _VIRTUALGATEWAYVIRTUALGATEWAYLISTENERTLSACMCERTIFICATE._serialized_end=8289
  _VIRTUALGATEWAYVIRTUALGATEWAYLISTENERTLSFILECERTIFICATE._serialized_start=8292
  _VIRTUALGATEWAYVIRTUALGATEWAYLISTENERTLSFILECERTIFICATE._serialized_end=8453
  _VIRTUALGATEWAYVIRTUALGATEWAYLISTENERTLSCERTIFICATE._serialized_start=8456
  _VIRTUALGATEWAYVIRTUALGATEWAYLISTENERTLSCERTIFICATE._serialized_end=8753
  _VIRTUALGATEWAYVIRTUALGATEWAYLISTENERTLS._serialized_start=8756
  _VIRTUALGATEWAYVIRTUALGATEWAYLISTENERTLS._serialized_end=8966
  _VIRTUALGATEWAYVIRTUALGATEWAYPORTMAPPING._serialized_start=8969
  _VIRTUALGATEWAYVIRTUALGATEWAYPORTMAPPING._serialized_end=9099
  _VIRTUALGATEWAYVIRTUALGATEWAYLISTENER._serialized_start=9102
  _VIRTUALGATEWAYVIRTUALGATEWAYLISTENER._serialized_end=9458
  _VIRTUALGATEWAYVIRTUALGATEWAYTLSVALIDATIONCONTEXTACMTRUST._serialized_start=9461
  _VIRTUALGATEWAYVIRTUALGATEWAYTLSVALIDATIONCONTEXTACMTRUST._serialized_end=9612
  _VIRTUALGATEWAYVIRTUALGATEWAYTLSVALIDATIONCONTEXTFILETRUST._serialized_start=9615
  _VIRTUALGATEWAYVIRTUALGATEWAYTLSVALIDATIONCONTEXTFILETRUST._serialized_end=9758
  _VIRTUALGATEWAYVIRTUALGATEWAYTLSVALIDATIONCONTEXTTRUST._serialized_start=9761
  _VIRTUALGATEWAYVIRTUALGATEWAYTLSVALIDATIONCONTEXTTRUST._serialized_end=10067
  _VIRTUALGATEWAYVIRTUALGATEWAYTLSVALIDATIONCONTEXT._serialized_start=10070
  _VIRTUALGATEWAYVIRTUALGATEWAYTLSVALIDATIONCONTEXT._serialized_end=10272
  _VIRTUALGATEWAYVIRTUALGATEWAYCLIENTPOLICYTLS._serialized_start=10275
  _VIRTUALGATEWAYVIRTUALGATEWAYCLIENTPOLICYTLS._serialized_end=10504
  _VIRTUALGATEWAYVIRTUALGATEWAYCLIENTPOLICY._serialized_start=10507
  _VIRTUALGATEWAYVIRTUALGATEWAYCLIENTPOLICY._serialized_end=10689
  _VIRTUALGATEWAYVIRTUALGATEWAYBACKENDDEFAULTS._serialized_start=10692
  _VIRTUALGATEWAYVIRTUALGATEWAYBACKENDDEFAULTS._serialized_end=10884
  _VIRTUALGATEWAYVIRTUALGATEWAYSPEC._serialized_start=10887
  _VIRTUALGATEWAYVIRTUALGATEWAYSPEC._serialized_end=11235
  _VIRTUALGATEWAY._serialized_start=11238
  _VIRTUALGATEWAY._serialized_end=11563
  _VIRTUALGATEWAY_TAGSENTRY._serialized_start=2049
  _VIRTUALGATEWAY_TAGSENTRY._serialized_end=2092
  _VIRTUALNODEFILEACCESSLOG._serialized_start=11565
  _VIRTUALNODEFILEACCESSLOG._serialized_end=11662
  _VIRTUALNODEACCESSLOG._serialized_start=11665
  _VIRTUALNODEACCESSLOG._serialized_end=11809
  _VIRTUALNODELOGGING._serialized_start=11812
  _VIRTUALNODELOGGING._serialized_end=11956
  _VIRTUALNODETLSVALIDATIONCONTEXTACMTRUST._serialized_start=11959
  _VIRTUALNODETLSVALIDATIONCONTEXTACMTRUST._serialized_end=12093
  _VIRTUALNODETLSVALIDATIONCONTEXTFILETRUST._serialized_start=12095
  _VIRTUALNODETLSVALIDATIONCONTEXTFILETRUST._serialized_end=12221
  _VIRTUALNODETLSVALIDATIONCONTEXTTRUST._serialized_start=12224
  _VIRTUALNODETLSVALIDATIONCONTEXTTRUST._serialized_end=12479
  _VIRTUALNODETLSVALIDATIONCONTEXT._serialized_start=12482
  _VIRTUALNODETLSVALIDATIONCONTEXT._serialized_end=12650
  _VIRTUALNODECLIENTPOLICYTLS._serialized_start=12653
  _VIRTUALNODECLIENTPOLICYTLS._serialized_end=12848
  _VIRTUALNODECLIENTPOLICY._serialized_start=12851
  _VIRTUALNODECLIENTPOLICY._serialized_end=12999
  _VIRTUALNODEVIRTUALSERVICEBACKEND._serialized_start=13002
  _VIRTUALNODEVIRTUALSERVICEBACKEND._serialized_end=13196
  _VIRTUALNODEBACKEND._serialized_start=13199
  _VIRTUALNODEBACKEND._serialized_end=13360
  _VIRTUALNODEDURATION._serialized_start=13362
  _VIRTUALNODEDURATION._serialized_end=13469
  _VIRTUALNODETCPTIMEOUT._serialized_start=13472
  _VIRTUALNODETCPTIMEOUT._serialized_end=13612
  _VIRTUALNODEHTTPTIMEOUT._serialized_start=13615
  _VIRTUALNODEHTTPTIMEOUT._serialized_end=13823
  _VIRTUALNODEGRPCTIMEOUT._serialized_start=13826
  _VIRTUALNODEGRPCTIMEOUT._serialized_end=14034
  _VIRTUALNODELISTENERTIMEOUT._serialized_start=14037
  _VIRTUALNODELISTENERTIMEOUT._serialized_end=14373
  _VIRTUALNODEHEALTHCHECK._serialized_start=14376
  _VIRTUALNODEHEALTHCHECK._serialized_end=14608
  _VIRTUALNODELISTENERTLSACMCERTIFICATE._serialized_start=14610
  _VIRTUALNODELISTENERTLSACMCERTIFICATE._serialized_end=14730
  _VIRTUALNODELISTENERTLSFILECERTIFICATE._serialized_start=14733
  _VIRTUALNODELISTENERTLSFILECERTIFICATE._serialized_end=14877
  _VIRTUALNODELISTENERTLSCERTIFICATE._serialized_start=14880
  _VIRTUALNODELISTENERTLSCERTIFICATE._serialized_end=15126
  _VIRTUALNODELISTENERTLS._serialized_start=15129
  _VIRTUALNODELISTENERTLS._serialized_end=15305
  _VIRTUALNODEPORTMAPPING._serialized_start=15307
  _VIRTUALNODEPORTMAPPING._serialized_end=15420
  _VIRTUALNODELISTENER._serialized_start=15423
  _VIRTUALNODELISTENER._serialized_end=15775
  _VIRTUALNODEBACKENDDEFAULTS._serialized_start=15778
  _VIRTUALNODEBACKENDDEFAULTS._serialized_end=15936
  _VIRTUALNODEDNSSERVICEDISCOVERY._serialized_start=15938
  _VIRTUALNODEDNSSERVICEDISCOVERY._serialized_end=16045
  _VIRTUALNODEAWSCLOUDMAPINSTANCEATTRIBUTE._serialized_start=16047
  _VIRTUALNODEAWSCLOUDMAPINSTANCEATTRIBUTE._serialized_end=16173
  _VIRTUALNODEAWSCLOUDMAPSERVICEDISCOVERY._serialized_start=16176
  _VIRTUALNODEAWSCLOUDMAPSERVICEDISCOVERY._serialized_end=16405
  _VIRTUALNODESERVICEDISCOVERY._serialized_start=16408
  _VIRTUALNODESERVICEDISCOVERY._serialized_end=16652
  _VIRTUALNODEVIRTUALNODESPEC._serialized_start=16655
  _VIRTUALNODEVIRTUALNODESPEC._serialized_end=17090
  _VIRTUALNODE._serialized_start=17093
  _VIRTUALNODE._serialized_end=17403
  _VIRTUALNODE_TAGSENTRY._serialized_start=2049
  _VIRTUALNODE_TAGSENTRY._serialized_end=2092
  _VIRTUALROUTERPORTMAPPING._serialized_start=17405
  _VIRTUALROUTERPORTMAPPING._serialized_end=17520
  _VIRTUALROUTERVIRTUALROUTERLISTENER._serialized_start=17523
  _VIRTUALROUTERVIRTUALROUTERLISTENER._serialized_end=17689
  _VIRTUALROUTERVIRTUALROUTERSPEC._serialized_start=17692
  _VIRTUALROUTERVIRTUALROUTERSPEC._serialized_end=17861
  _VIRTUALROUTER._serialized_start=17864
  _VIRTUALROUTER._serialized_end=18184
  _VIRTUALROUTER_TAGSENTRY._serialized_start=2049
  _VIRTUALROUTER_TAGSENTRY._serialized_end=2092
  _VIRTUALSERVICEVIRTUALNODESERVICEPROVIDER._serialized_start=18186
  _VIRTUALSERVICEVIRTUALNODESERVICEPROVIDER._serialized_end=18312
  _VIRTUALSERVICEVIRTUALROUTERSERVICEPROVIDER._serialized_start=18315
  _VIRTUALSERVICEVIRTUALROUTERSERVICEPROVIDER._serialized_end=18445
  _VIRTUALSERVICEVIRTUALSERVICEPROVIDER._serialized_start=18448
  _VIRTUALSERVICEVIRTUALSERVICEPROVIDER._serialized_end=18725
  _VIRTUALSERVICEVIRTUALSERVICESPEC._serialized_start=18728
  _VIRTUALSERVICEVIRTUALSERVICESPEC._serialized_end=18900
  _VIRTUALSERVICE._serialized_start=18903
  _VIRTUALSERVICE._serialized_end=19228
  _VIRTUALSERVICE_TAGSENTRY._serialized_start=2049
  _VIRTUALSERVICE_TAGSENTRY._serialized_end=2092
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class LoadBalancerAccessLoggingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EMIT_INTERVAL_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    S3_BUCKET_NAME_FIELD_NUMBER: builtins.int
    S3_BUCKET_PREFIX_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    emit_interval: builtins.int
    enabled: builtins.bool
    s3_bucket_name: builtins.str
    s3_bucket_prefix: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        emit_interval: builtins.int = ...,
        enabled: builtins.bool = ...,
        s3_bucket_name: builtins.str = ...,
        s3_bucket_prefix: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["emit_interval", b"emit_interval", "enabled", b"enabled", "resource_info", b"resource_info", "s3_bucket_name", b"s3_bucket_name", "s3_bucket_prefix", b"s3_bucket_prefix"]) -> None: ...

global___LoadBalancerAccessLoggingPolicy = LoadBalancerAccessLoggingPolicy

@typing_extensions.final
class LoadBalancerAppCookieStickinessPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COOKIE_NAME_FIELD_NUMBER: builtins.int
    POLICY_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cookie_name: builtins.str
    policy_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cookie_name: builtins.str = ...,
        policy_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cookie_name", b"cookie_name", "policy_name", b"policy_name", "resource_info", b"resource_info"]) -> None: ...

global___LoadBalancerAppCookieStickinessPolicy = LoadBalancerAppCookieStickinessPolicy

@typing_extensions.final
class LoadBalancerConnectionDrainingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled: builtins.bool
    timeout: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled: builtins.bool = ...,
        timeout: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "resource_info", b"resource_info", "timeout", b"timeout"]) -> None: ...

global___LoadBalancerConnectionDrainingPolicy = LoadBalancerConnectionDrainingPolicy

@typing_extensions.final
class LoadBalancerConnectionSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDLE_TIMEOUT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    idle_timeout: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        idle_timeout: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["idle_timeout", b"idle_timeout", "resource_info", b"resource_info"]) -> None: ...

global___LoadBalancerConnectionSettings = LoadBalancerConnectionSettings

@typing_extensions.final
class LoadBalancerHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HEALTHY_THRESHOLD_FIELD_NUMBER: builtins.int
    INTERVAL_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    UNHEALTHY_THRESHOLD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    healthy_threshold: builtins.str
    interval: builtins.str
    target: builtins.str
    timeout: builtins.str
    unhealthy_threshold: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        healthy_threshold: builtins.str = ...,
        interval: builtins.str = ...,
        target: builtins.str = ...,
        timeout: builtins.str = ...,
        unhealthy_threshold: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["healthy_threshold", b"healthy_threshold", "interval", b"interval", "resource_info", b"resource_info", "target", b"target", "timeout", b"timeout", "unhealthy_threshold", b"unhealthy_threshold"]) -> None: ...

global___LoadBalancerHealthCheck = LoadBalancerHealthCheck

@typing_extensions.final
class LoadBalancerLBCookieStickinessPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COOKIE_EXPIRATION_PERIOD_FIELD_NUMBER: builtins.int
    POLICY_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cookie_expiration_period: builtins.str
    policy_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cookie_expiration_period: builtins.str = ...,
        policy_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cookie_expiration_period", b"cookie_expiration_period", "policy_name", b"policy_name", "resource_info", b"resource_info"]) -> None: ...

global___LoadBalancerLBCookieStickinessPolicy = LoadBalancerLBCookieStickinessPolicy

@typing_extensions.final
class LoadBalancerListeners(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INSTANCE_PORT_FIELD_NUMBER: builtins.int
    INSTANCE_PROTOCOL_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_PORT_FIELD_NUMBER: builtins.int
    POLICY_NAMES_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    SSL_CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    instance_port: builtins.str
    instance_protocol: builtins.str
    load_balancer_port: builtins.str
    @property
    def policy_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    protocol: builtins.str
    ssl_certificate_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        instance_port: builtins.str = ...,
        instance_protocol: builtins.str = ...,
        load_balancer_port: builtins.str = ...,
        policy_names: collections.abc.Iterable[builtins.str] | None = ...,
        protocol: builtins.str = ...,
        ssl_certificate_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_port", b"instance_port", "instance_protocol", b"instance_protocol", "load_balancer_port", b"load_balancer_port", "policy_names", b"policy_names", "protocol", b"protocol", "resource_info", b"resource_info", "ssl_certificate_id", b"ssl_certificate_id"]) -> None: ...

global___LoadBalancerListeners = LoadBalancerListeners

@typing_extensions.final
class LoadBalancerPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    INSTANCE_PORTS_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_PORTS_FIELD_NUMBER: builtins.int
    POLICY_NAME_FIELD_NUMBER: builtins.int
    POLICY_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def attributes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def instance_ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def load_balancer_ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    policy_name: builtins.str
    policy_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        attributes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        instance_ports: collections.abc.Iterable[builtins.str] | None = ...,
        load_balancer_ports: collections.abc.Iterable[builtins.str] | None = ...,
        policy_name: builtins.str = ...,
        policy_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attributes", b"attributes", "instance_ports", b"instance_ports", "load_balancer_ports", b"load_balancer_ports", "policy_name", b"policy_name", "policy_type", b"policy_type", "resource_info", b"resource_info"]) -> None: ...

global___LoadBalancerPolicies = LoadBalancerPolicies

@typing_extensions.final
class LoadBalancer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACCESS_LOGGING_POLICY_FIELD_NUMBER: builtins.int
    APP_COOKIE_STICKINESS_POLICY_FIELD_NUMBER: builtins.int
    AVAILABILITY_ZONES_FIELD_NUMBER: builtins.int
    CONNECTION_DRAINING_POLICY_FIELD_NUMBER: builtins.int
    CONNECTION_SETTINGS_FIELD_NUMBER: builtins.int
    CROSS_ZONE_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_FIELD_NUMBER: builtins.int
    INSTANCES_FIELD_NUMBER: builtins.int
    LB_COOKIE_STICKINESS_POLICY_FIELD_NUMBER: builtins.int
    LISTENERS_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_NAME_FIELD_NUMBER: builtins.int
    POLICIES_FIELD_NUMBER: builtins.int
    SCHEME_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    SUBNETS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def access_logging_policy(self) -> global___LoadBalancerAccessLoggingPolicy: ...
    @property
    def app_cookie_stickiness_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LoadBalancerAppCookieStickinessPolicy]: ...
    @property
    def availability_zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def connection_draining_policy(self) -> global___LoadBalancerConnectionDrainingPolicy: ...
    @property
    def connection_settings(self) -> global___LoadBalancerConnectionSettings: ...
    cross_zone: builtins.bool
    @property
    def health_check(self) -> global___LoadBalancerHealthCheck: ...
    @property
    def instances(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def lb_cookie_stickiness_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LoadBalancerLBCookieStickinessPolicy]: ...
    @property
    def listeners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LoadBalancerListeners]: ...
    load_balancer_name: builtins.str
    @property
    def policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LoadBalancerPolicies]: ...
    scheme: builtins.str
    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def subnets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        access_logging_policy: global___LoadBalancerAccessLoggingPolicy | None = ...,
        app_cookie_stickiness_policy: collections.abc.Iterable[global___LoadBalancerAppCookieStickinessPolicy] | None = ...,
        availability_zones: collections.abc.Iterable[builtins.str] | None = ...,
        connection_draining_policy: global___LoadBalancerConnectionDrainingPolicy | None = ...,
        connection_settings: global___LoadBalancerConnectionSettings | None = ...,
        cross_zone: builtins.bool = ...,
        health_check: global___LoadBalancerHealthCheck | None = ...,
        instances: collections.abc.Iterable[builtins.str] | None = ...,
        lb_cookie_stickiness_policy: collections.abc.Iterable[global___LoadBalancerLBCookieStickinessPolicy] | None = ...,
        listeners: collections.abc.Iterable[global___LoadBalancerListeners] | None = ...,
        load_balancer_name: builtins.str = ...,
        policies: collections.abc.Iterable[global___LoadBalancerPolicies] | None = ...,
        scheme: builtins.str = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        subnets: collections.abc.Iterable[builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["access_logging_policy", b"access_logging_policy", "connection_draining_policy", b"connection_draining_policy", "connection_settings", b"connection_settings", "health_check", b"health_check", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_logging_policy", b"access_logging_policy", "app_cookie_stickiness_policy", b"app_cookie_stickiness_policy", "availability_zones", b"availability_zones", "connection_draining_policy", b"connection_draining_policy", "connection_settings", b"connection_settings", "cross_zone", b"cross_zone", "health_check", b"health_check", "instances", b"instances", "lb_cookie_stickiness_policy", b"lb_cookie_stickiness_policy", "listeners", b"listeners", "load_balancer_name", b"load_balancer_name", "policies", b"policies", "resource_info", b"resource_info", "scheme", b"scheme", "security_groups", b"security_groups", "subnets", b"subnets", "tags", b"tags"]) -> None: ...

global___LoadBalancer = LoadBalancer

@typing_extensions.final
class ElasticLoadBalancing(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_FIELD_NUMBER: builtins.int
    @property
    def load_balancer(self) -> global___LoadBalancer: ...
    def __init__(
        self,
        *,
        load_balancer: global___LoadBalancer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["load_balancer", b"load_balancer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["load_balancer", b"load_balancer"]) -> None: ...

global___ElasticLoadBalancing = ElasticLoadBalancing



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Info(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_DATE_FIELD_NUMBER: builtins.int
    COMPILER_FIELD_NUMBER: builtins.int
    GIT_COMMIT_FIELD_NUMBER: builtins.int
    GIT_TREE_STATE_FIELD_NUMBER: builtins.int
    GIT_VERSION_FIELD_NUMBER: builtins.int
    GO_VERSION_FIELD_NUMBER: builtins.int
    MAJOR_FIELD_NUMBER: builtins.int
    MINOR_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    build_date: builtins.str
    compiler: builtins.str
    git_commit: builtins.str
    git_tree_state: builtins.str
    git_version: builtins.str
    go_version: builtins.str
    major: builtins.str
    minor: builtins.str
    platform: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        build_date: builtins.str = ...,
        compiler: builtins.str = ...,
        git_commit: builtins.str = ...,
        git_tree_state: builtins.str = ...,
        git_version: builtins.str = ...,
        go_version: builtins.str = ...,
        major: builtins.str = ...,
        minor: builtins.str = ...,
        platform: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_date", b"build_date", "compiler", b"compiler", "git_commit", b"git_commit", "git_tree_state", b"git_tree_state", "git_version", b"git_version", "go_version", b"go_version", "major", b"major", "minor", b"minor", "platform", b"platform", "resource_info", b"resource_info"]) -> None: ...

global___Info = Info
